==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/DikiCGI/PageFactory.pm <==
#
# WiKicker
#
#  PageFactory.pm
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: PageFactory.pm,v 1.1 2004/05/30 04:18:59 naney Exp $
#
#

package WiKicker::DikiCGI::PageFactory;

use 5.005;
use strict;
use WiKicker::Loader;

sub new {
  my $class = shift;

  my $self = bless {}, $class;

  return $self;
}

sub create {
  my ($self, $request) = @_;

  my $page_class = $self->get_page_class($request);

  WiKicker::Loader::load_module($page_class);

  my $page;
  eval {
    $page = $page_class->new(request => $request);
  };
  if ($@) {
    die "Can't create page object $page: $@";
  }
  return $page;
}

use vars qw(%page_class_map);
BEGIN {
  %page_class_map = ( 'd' => 'WiKicker::DikiCGI::Page::DiaryPage',
                      'dk' => 'WiKicker::DikiCGI::Page::KeywordDiaryPage');
}

sub get_page_class {
  my ($self, $request) = @_;

  my $command_type = $request->command->type;
  if (exists $page_class_map{$command_type}) {
    return $page_class_map{$command_type};
  }

  return 'WiKicker::DikiCGI::Page::UnknownPage';
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/DikiCGI/PageFactory.pm <==
#
# WiKicker
#
#  PageFactory.pm
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: PageFactory.pm,v 1.2 2004/08/03 12:55:52 naney Exp $
#
#

package WiKicker::DikiCGI::PageFactory;

use 5.005;
use strict;
use WiKicker::Loader;

sub new {
  my $class = shift;

  my $self = bless {}, $class;

  return $self;
}

sub create {
  my ($self, $request) = @_;

  my $page_class = $self->get_page_class($request);

  WiKicker::Loader::load_module($page_class);

  my $page;
  eval {
    $page = $page_class->new(request => $request);
  };
  if ($@) {
    die "Can't create page object $page: $@";
  }
  return $page;
}

use vars qw(%page_class_map);
BEGIN {
  %page_class_map = ( 'd' => 'WiKicker::DikiCGI::Page::DiaryPage',
                      'dk' => 'WiKicker::DikiCGI::Page::KeywordDiaryPage',
                      'term_list' => 'WiKicker::DikiCGI::Page::TermListPage',
                    );
}

sub get_page_class {
  my ($self, $request) = @_;

  my $command_type = $request->command->type;
  if (exists $page_class_map{$command_type}) {
    return $page_class_map{$command_type};
  }

  return 'WiKicker::DikiCGI::Page::UnknownPage';
}

1;
